@@ -2,32 +2,26 @@ from .CameraContext import CameraContext
 from .GraphComponent import GraphComponent
 from .JsonView import JsonView
 from .MatSidebar import MatSidebar
+from .Scrollspy import Scrollspy
 from .Simple3DScene import Simple3DScene
 from .PeriodicContext import PeriodicContext
 from .PeriodicContextTable import PeriodicContextTable
 from .PeriodicElement import PeriodicElement
 from .PeriodicFilter import PeriodicFilter
 from .PeriodicTableInput import PeriodicTableInput
-from .MatMaterialsTable import MatMaterialsTable
-from .MatPrintViewContext import MatPrintViewContext
-from .MatSearchGrid import MatSearchGrid
-from .Search import Search
-from .SearchGrid import SearchGrid
+from .SearchUI import SearchUI
 
 __all__ = [
     "CameraContext",
     "GraphComponent",
     "JsonView",
     "MatSidebar",
+    "Scrollspy",
     "Simple3DScene",
     "PeriodicContext",
     "PeriodicContextTable",
     "PeriodicElement",
     "PeriodicFilter",
     "PeriodicTableInput",
-    "MatMaterialsTable",
-    "MatPrintViewContext",
-    "MatSearchGrid",
-    "Search",
-    "SearchGrid"
+    "SearchUI"
 ]
\ No newline at end of file
